@@ -6,16 +6,16 @@ from __future__ import annotations
 
 import os
 import sys
-from collections.abc import ItemsView, Sequence
+import warnings
+from collections.abc import Sequence
 from dataclasses import dataclass
 from typing import TYPE_CHECKING, Literal
-
 if TYPE_CHECKING:
     from types import FrameType
     from typing import Any, Callable, ItemsView, Sized
 
 #: The release version
-version = '2.1.2'
+version = '2.1.10'
 __version__ = version
 
 MIN_PYTHON_VERSION = 3, 8
@@ -30,20 +30,16 @@ compat_platform = sys.platform
 if "bsd" in compat_platform:
     compat_platform = "linux-compat"
 
-_enable_optimisations = not __debug__
-if getattr(sys, "frozen", None):
-    _enable_optimisations = True
+if compat_platform == "cygwin":
+    # This hack pretends that the posix-like ctypes provides windows
+    # functionality.  COM does not work with this hack, so there is no
+    # DirectSound support.
+    import ctypes
 
-
-_SPECIAL_OPTION_VALIDATORS = {
-    "audio": lambda x: isinstance(x, Sequence),
-    "vsync": lambda x: x is None or isinstance(x, bool),
-}
-
-_OPTION_TYPE_VALIDATORS = {
-    "bool": lambda x: isinstance(x, bool),
-    "int": lambda x: isinstance(x, int),
-}
+    ctypes.windll = ctypes.cdll
+    ctypes.oledll = ctypes.cdll
+    ctypes.WINFUNCTYPE = ctypes.CFUNCTYPE
+    ctypes.HRESULT = ctypes.c_long
 
 
 @dataclass
@@ -110,8 +106,12 @@ class Options:
     debug_trace_depth: int = 1
     debug_trace_flush: bool = True
 
+    debug_com: bool = False
+    """If ``True``, prints information on COM calls. This can potentially help narrow down issues with certain libraries
+    that utilize COM calls. Only applies to the Windows platform."""
+
     debug_win32: bool = False
-    """If ``True``, prints error messages related to Windows library calls. Usually get's information from
+    """If ``True``, prints error messages related to Windows library calls. Usually gets information from
     ``Kernel32.GetLastError``. This information is output to a file called ``debug_win32.log``."""
 
     debug_input: bool = False
@@ -175,6 +175,11 @@ class Options:
     .. versionadded:: 2.0
     """
 
+    text_antialiasing: bool = True
+    """If ``True``, font renderers will improve text quality by adding antialiasing to the rendered characters. If
+    ``False``, text quality will appear pixelated.
+    """
+
     headless: bool = False
     """If ``True``, visible Windows are not created and a running desktop environment is not required. This option
     is useful when running pyglet on a headless server, or compute cluster. OpenGL drivers with ``EGL`` support are
@@ -186,14 +191,17 @@ class Options:
     GPU to use. This is only useful on multi-GPU systems.
     """
 
-    win32_disable_shaping: bool = False
-    """If ``True``, will disable the shaping process for the default Windows font renderer to offer a performance
-    speed up. If your font is simple, monospaced, or you require no advanced OpenType features, this option may be
-    useful. You can try enabling this to see if there is any impact on clarity for your font. The advance will be
-    determined by the glyph width.
+    text_shaping: Literal["platform", "harfbuzz", False] = 'platform'
+    """Determines how text is processed and displayed based on features of the font.
 
-    .. note:: Shaping is the process of determining which character glyphs to use and specific placements of those
-       glyphs when given a full string of characters.
+    Valid option names are:
+
+     * ``False``, Disables the shaping process for text. This may increase performance as it reduces the amount
+        of calls during rendering. If your font is simple, monospaced, or you require no advanced OpenType features,
+        this option may be useful.
+     * ``'platform'``, Uses platform's font system for shaping. Supported by Windows (DirectWrite) and Mac (CoreText).
+     * ``'harfbuzz'``, Utilize the harfbuzz library for font shaping. This requires an optional dependency, if not
+     found, it will fallback to platform shaping.
 
     .. versionadded:: 2.0
     """
@@ -247,8 +255,8 @@ class Options:
 
     .. versionadded:: 2.0.5"""
 
-    dpi_scaling: Literal["real", "scaled", "stretch", "platform"] = "real"
-    """For 'HiDPI' displays, Window behavior can differ between operating systems. Defaults to `'real'`.
+    dpi_scaling: Literal["real", "scaled", "stretch", "platform"] = "platform"
+    """For 'HiDPI' displays, Window behavior can differ between operating systems. Defaults to `'platform'`.
 
     The current options are an attempt to create consistent behavior across all of the operating systems.
 
@@ -270,7 +278,7 @@ class Options:
     rescaling and repositioning of content will be necessary, but at the cost of blurry content depending on the extent
     of the stretch. For example, 800x600 at 150% DPI will be 800x600 for `window.get_size()` and 1200x900 for
     `window.get_framebuffer_size()`.
-    
+
     `'platform'`: A DPI aware window is created, however window sizing and framebuffer sizing is not interfered with
     by Pyglet. Final sizes are dictated by the platform the window was created on. It is up to the user to make any
     platform adjustments themselves such as sizing on a platform, mouse coordinate adjustments, or framebuffer size
@@ -299,42 +307,31 @@ class Options:
         return self.__dict__[item]
 
     def __setitem__(self, key: str, value: Any) -> None:
-        assert key in self.__annotations__, f"Invalid option name: '{key}'"
-        assert (_SPECIAL_OPTION_VALIDATORS.get(key) or _OPTION_TYPE_VALIDATORS[self.__annotations__[key]])(value), \
-            f"Invalid type: '{type(value)}' for '{key}'"
         self.__dict__[key] = value
 
 
 #: Instance of :py:class:`~pyglet.Options` used to set runtime options.
 options: Options = Options()
 
-_OPTION_TYPE_REMAPS = {
-    "audio": "sequence",
-    "vsync": "bool",
-}
 
-for _key, _type in options.__annotations__.items():
+for _option_name, _type_str in options.__annotations__.items():
     """Check Environment Variables for pyglet options"""
-    if _value := os.environ.get(f"PYGLET_{_key.upper()}"):
-        _type = _OPTION_TYPE_REMAPS.get(_key, _type)
-        if _type == 'sequence':
-            options[_key] = _value.split(",")
-        elif _type == 'bool':
-            options[_key] = _value in ("true", "TRUE", "True", "1")
-        elif _type == 'int':
-            options[_key] = int(_value)
+    if _value := os.environ.get(f"PYGLET_{_option_name.upper()}"):
+        if 'Sequence' in _type_str:
+            setattr(options, _option_name, _value.split(","))
+        elif 'bool' in _type_str:
+            setattr(options, _option_name, _value in ("true", "TRUE", "True", "1"))
+        elif 'int' in _type_str:
+            setattr(options, _option_name, int(_value))
+        elif 'Literal' in _type_str and _value in _type_str:
+            setattr(options, _option_name, _value)
+        else:
+            warnings.warn(f"Invalid value '{_value}' for {_option_name}. Expecting {_type_str}")
 
 
-if compat_platform == "cygwin":
-    # This hack pretends that the posix-like ctypes provides windows
-    # functionality.  COM does not work with this hack, so there is no
-    # DirectSound support.
-    import ctypes
+if (__debug__ is False) or getattr(sys, "frozen", False):
+    options.debug_gl = False
 
-    ctypes.windll = ctypes.cdll
-    ctypes.oledll = ctypes.cdll
-    ctypes.WINFUNCTYPE = ctypes.CFUNCTYPE
-    ctypes.HRESULT = ctypes.c_long
 
 # Call tracing
 # ------------
